/* $Id: Stars.java,v 1.11 2004/04/07 14:16:47 mit Exp $ */
/* Stars.java */
import java.text.DecimalFormat;

public class Stars{
    private String name, spect;
    private int numb, link;
    private double rade, lode, cand; 
    private static int count;
    private DecimalFormat df1 = new DecimalFormat("#0.0#");

    private final String spec = "OBAFGKMNCSRWx";
    private final int [] specn = {0,1,2,3,4,5,6,7,7,6,6,6,0,2};
    private final String [] nam = {
	"and","ant","aps","aql","aqr","ara","ari","aur","boo","cae",
	"cam","cap","car","cas","cen","cep","cet","cha","cir","cma",
	"cmi","cnc","col","com","cra","crb","crt","cru","crv","cvn",
	"cyg","del","dor","dra","equ","eri","for","gem","gru","her",
	"hor","hya","hyi","ind","lac","leo","lep","lib","lmi","lup",
	"lyn","lyr","men","mic","mon","mus","nor","oct","oph","ori",
	"pav","peg","per","phe","pic","psa","psc","pup","pyx","ret",
	"scl","sco","sct","ser","sex","sge","sgr","tau","tel","tra",
	"tri","tuc","uma","umi","vel","vir","vol","vul"};
    private final String [] names = {
	"Andromeda","Antlia","Apus","Aquila","Aquarius",
	"Ara","Aries","Auriga","Bootes","Caelum",
	"Camelopardalis","Capricornus","Carina","Cassiopeia","Centaurus",
	"Cepheus","Cetus","Chamaeleon","Circinus","Canis Major",
	"Canis Minor","Cancer","Columba","Coma","Corona Australis",
	"Corona Borealis","Crater","Crux","Corvus","Canes Venatici",
	"Cygnus","Delphinus","Dorado","Draco","Equuleus",
	"Eridanus","Fornax","Gemini","Grus","Hercules",
	"Horologium","Hydra","Hydrus","Indus","Lacerta",
	"Leo","Lepus","Libra","Leo Minor","Lupus",
	"Lynx","Lyra","Mensa","Microscopium","Monoceros",
	"Musca","Norma","Octans","Ophiuchus","Orion",
	"Pavo","Pegasus","Perseus","Phoenix","Pictor",
	"Piscis Austrinus","Pisces","Puppis","Pyxis","Reticulm",
	"Sculptor","Scorpius","Scutum","Serpens","Sextans",
	"Sagitta","Sagittarius","Taurus","Telescopium","Triangulum Australe",
	"Triangulum","Tucana","Ursa Major","Ursa Minor","Vela",
	"Virgo","Volans","Vulpecula"};
    private final int NM = 0;
    private final int RA = 1;
    private final int DC = 2;
    private final int CO = 3;
    private final int CL = 4;
    private final int LN = 5;
    
    public Stars() {
	setStars(0,0,0,0,"","");
    }
    public Stars(int nm, double ra, double dc, double ca, String sp, String li) {
	setStars(nm, ra, dc, ca, sp, li);
    }
    public void setStars(int nm, double ra, double dc, double ca, String sp, String li) {
	numb = nm;
	rade = ra;
	lode = dc;
	cand = ca;
	spect = sp.substring(0,1);
	name = (li.length() > 0) ? li.substring(0,3) : "";
	link = (li.length() > 0) ? Integer.parseInt(li.substring(3, li.length())) : 0;
	++count;
    }
    public double getRA(){
	return this.toRadians(rade);
    }
    public double getDC(){
	return this.toRadians(lode);
    }
    public double getCandela(){
	return cand;
    }
    public int getColor(){
	int s = spec.indexOf(spect);
	return specn[s];
    }
    public String getSpectrum() {
	return spect;
    }
    public String getName() {
	for (int i = 0; i < nam.length; i++) {
	    if (nam[i].equals(name))
		return names[i];
	}
	return "";
    }
    public int getLink(){
	return (link > 0) ? link : -1;
    }
    public int getNum() {
	for (int i = 0; i < nam.length; i++) {
	    if (nam[i].equals(name))
		return i+1;
	}
	return -1;
    }
    public static int getAllnum() {
	return count;
    }
    public double toRadians(double d) {
        return d*Math.PI/180.0;
    }
    public double toDegrees(double r) {
        return r*180.0/Math.PI;
    }
    public String dform(double n) {
	return df1.format((float)n);
    }
    public String toString(){
	StringBuffer stb = new StringBuffer(48);
	stb.append(numb+":"+this.getName());
	stb.append(" "+dform(rade/15)+"h");
	stb.append(" "+dform(lode)+"`");
	stb.append(" "+this.getSpectrum());
	stb.append(" "+this.getCandela());
	return stb.toString();
    }
}
